#!/bin/bash

#---( Slackware Build Script
#---( Build Script written for GPerf
#---( Source URL: http://mirrors.usc.edu/pub/gnu/gperf/gperf-3.0.2.tar.gz
#---( Build script by R S Ananda Murthy (rsamurti@airtelbroadband.in)
#---( Date build script was last modified: Tuesday, September 10 2006.


#------------------( Set Package Name & Version )


soft='gperf'
softversion='3.0.2'
packageversion='1rsa'


#------------------( Set Package CPU Architecture Optimizations )


arch='i486'
cpu='i686'


#------------------( Set Build Location Variables )


buildir=$(pwd)
srcpkg="$buildir/$soft-$softversion.tar.gz"
src="$buildir/$soft-$softversion"
package="$soft-$softversion-$arch-$packageversion"
dest="$buildir/$package"


#------------------( Clean, prepare the work area and extract the source code )


cd $buildir
rm -rf $src
tar -xvf $srcpkg
rm -f $dest.tgz
rm -rf $dest
mkdir -p $dest


#------------------( Set Build Ownerships and CFLAGS )


chown -R root:root .
export CFLAGS="-O2 -march=$arch -mtune=$cpu" 


#------------------( Configure, Make And Install The Software )


cd $src

./configure --prefix=/usr --build=i486-slackware-linux \
--mandir=/usr/man
make
make install DESTDIR=$dest


#------------------( Strip Executables (Comment out these lines if debugging info is needed) )


( cd $dest
  find . | xargs file | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded
)

( cd $dest
  find . | xargs file | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded
)


#------------------( Compress Man Pages and Info Pages and Move To Correct Location )


( cd $dest/usr/man
  find . -name "*.?" | xargs gzip -9
)

( cd $dest/usr/info
  find . -name "*.info" | xargs gzip -9
  rm -f dir
)


#------------------( Move Documentation To Correct Location )


mkdir -p $dest/usr/doc/$soft-$softversion
mkdir -p $dest/usr/doc/$soft-$softversion/HTML
cp -a \
  AUTHORS COPYING ChangeLog NEWS README INSTALL \
  $dest/usr/doc/$soft-$softversion
cp ./doc/*.html $dest/usr/doc/$soft-$softversion/HTML
cp ./doc/*.pdf $dest/usr/doc/$soft-$softversion
rm -rf $dest/usr/share


#------------------( Copy Build The Script )


mkdir -p $dest/usr/src/$soft-$softversion
cp $buildir/build-$soft.sh $dest/usr/src/$soft-$softversion/build-$soft.sh
chmod -x $dest/usr/src/$soft-$softversion/build-$soft.sh


#------------------( Create The Slackdesc )


mkdir -p $dest/install
cat <<EOF > $dest/install/slack-desc 
    |-----handy-ruler------------------------------------------------------|
gperf: gperf (GNU Perfect Hash Function Generator)
gperf: 
gperf: GNU gperf is a program that generates perfect hash functions for sets
gperf: of keywords. A perfect hash function is a hash function and a data
gperf: structure that allows recognition of a key word in a set of words
gperf: using exactly 1 probe into the data structure. Output from the GPERF
gperf: program is used to recognize reserved words in the GNU C, GNU C++,
gperf: and GNU Pascal compilers, as well as with the GNU indent program.
gperf:
gperf:
gperf: Compiled by R S Ananda Murthy on a Slackware-11.0 system.
EOF

#------------------( Create The doinst.sh File)

cat <<EOF > $dest/install/doinst.sh
## This installs info directory informtation for the package.
echo
echo "Installing info directory entry..."
if [ -x /usr/bin/install-info ]
then
   /usr/bin/install-info --info-dir=/usr/info /usr/info/gperf.info.gz 2>/dev/null
fi
EOF


#------------------( Create The slack-required File)

cat <<EOF > $dest/install/slack-required
EOF


#------------------( Compress The Package And Clean Up The Work Area )


cd $dest
makepkg -l y -c n $package.tgz
mv $package.tgz ../$package.tgz
rm -rf $src
rm -rf $dest


#------------------( Generate the MD5 Check Sum )


cd $buildir
md5sum $package.tgz > $package.md5